@@ -9,7 +9,7 @@ import platform, subprocess
 import urllib2, tarfile, tempfile, StringIO, shutil
 
 sample_ini_url='http://www.magikmon.com/download/mksbackup/sample.ini'
-ghettovcb_url='http://www.magikmon.com/download/mksbackup/ghettoVCB-20110628.tar.gz'
+ghettovcb_url='http://www.magikmon.com/download/mksbackup/ghettoVCB-mksbackup-last.tar.gz'
 readme_txt_url='http://www.magikmon.com/download/mksbackup/README.txt'
 #ftpput_url='http://www.magikmon.com/download/mksbackup/ftpput'
 
